package org.apache.bcel.util;

import java.util.LinkedHashMap;
import java.util.Map;
import org.apache.bcel.classfile.JavaClass;

/* loaded from: org_apache_bcel_util.jar:org/apache/bcel/util/LruCacheClassPathRepository.class */
public class LruCacheClassPathRepository extends AbstractClassPathRepository {
    private final LinkedHashMap<String, JavaClass> loadedClasses;

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public /* bridge */ /* synthetic */ JavaClass loadClass(String str) throws ClassNotFoundException {
        return super.loadClass(str);
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public /* bridge */ /* synthetic */ JavaClass loadClass(Class cls) throws ClassNotFoundException {
        return super.loadClass((Class<?>) cls);
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public /* bridge */ /* synthetic */ ClassPath getClassPath() {
        return super.getClassPath();
    }

    public LruCacheClassPathRepository(ClassPath path, final int cacheSize) {
        super(path);
        if (cacheSize < 1) {
            throw new IllegalArgumentException("cacheSize must be a positive number.");
        }
        int initialCapacity = (int) (0.75d * cacheSize);
        this.loadedClasses = new LinkedHashMap<String, JavaClass>(initialCapacity, cacheSize, true) { // from class: org.apache.bcel.util.LruCacheClassPathRepository.1
            private static final long serialVersionUID = 1;

            @Override // java.util.LinkedHashMap
            protected boolean removeEldestEntry(Map.Entry<String, JavaClass> eldest) {
                return size() > cacheSize;
            }
        };
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public void clear() {
        this.loadedClasses.clear();
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public JavaClass findClass(String className) {
        return this.loadedClasses.get(className);
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public void removeClass(JavaClass javaClass) {
        this.loadedClasses.remove(javaClass.getClassName());
    }

    @Override // org.apache.bcel.util.AbstractClassPathRepository, org.apache.bcel.util.Repository
    public void storeClass(JavaClass javaClass) {
        this.loadedClasses.put(javaClass.getClassName(), javaClass);
        javaClass.setRepository(this);
    }
}
